@@ -32,10 +32,17 @@ public:
     int count();
     void setOptions(int _num,QString _value);
     void setCodecName(int _num,QString _value);
+    void setEncoder(int _num,QString _value);
+    void setExtension(int _num,QString _value);
     QString getOptions(int _num);
     QString getCodecName(int _num);
+    QString getEncoder(int _num);
+    QString getExtension(int _num);
     void remove(int _num);
     void reset();
+    static int getAbsCodecNum(int _num,const QString &_encoder);
+
+
 private:
     QMap <int,_k9AudioCodec> m_codecs;
     k9Config *m_config;
