@@ -26,12 +26,11 @@
 #ifdef __FreeBSD__
     #include <osreldate.h>
 #endif
-#include <dvdread/ifo_types.h>
-#include <dvdread/dvd_reader.h>
-#include <dvdread/ifo_read.h>
-#include <dvdread/ifo_print.h>
-#include <dvdread/nav_read.h>
-#include <dvdread/nav_types.h>
+#include "ifo_types.h"
+#include "dvd_reader.h"
+#include "ifo_read.h"
+#include "nav_read.h"
+#include "nav_types.h"
 
 #include <qobject.h>
 
@@ -44,3 +43,5 @@
 	#define NDEBUG
 #endif
 #include <QtDebug>
+#include "k9dialogs.h"
+#include "k9config.h"
