@@ -33,13 +33,19 @@ public:
     void wait();
     bool isRunning();
     bool normalExit();
+    void setDebugOutput(bool theValue);
+	
 private:
     bool m_waitSync;
     bool m_shellCmd;
     QString m_debug;
+    bool m_debugOutput;
     QTime m_elapsed;
     QEventLoop *m_eventLoop;
     void syncStart();
+protected:
+   virtual void getStdout(QByteArray data);
+   virtual void getStderr(QByteArray data);
 private slots:
    void slotReadyReadStandardError ();
    void slotReadyReadStandardOutput ();
