@@ -24,9 +24,8 @@ k9LvItemImport::k9LvItemImport( QTreeWidgetItem *parent,eObjectType _objectType)
 
 
 bool k9LvItemImport::operator< ( const QTreeWidgetItem & other ) const   {
- int col=treeWidget()->sortColumn();
+// int col=treeWidget()->sortColumn();
 
- int res;
  if (other.type()== TITLE) {
      k9LvItemImport *item2=(k9LvItemImport*)&other;
      return   this->getTitle()->getNum() < item2->getTitle()->getNum();
