@@ -13,7 +13,7 @@
 #include "k9newdvd.h"
 #include "k9menu.h"
 
-k9Title::k9Title(k9NewDVD *parent, const char *name)
+k9Title::k9Title(k9NewDVD *parent, const char *)
  : QObject(parent)
 {
     m_num=parent->getTitles()->count();
@@ -26,7 +26,7 @@ k9Title::k9Title(k9NewDVD *parent, const char *name)
 k9Title::~k9Title()
 {
    k9NewDVD *p=(k9NewDVD*)parent();
-   p->getRootMenu()->removeButton(m_button);
+   // p->getRootMenu()->removeButton(m_button);
 }
 
 bool k9TitleItems::compareItems(k9AviFile *item1,k9AviFile *item2) {
