@@ -19,6 +19,7 @@
 #include "k9prefmencoder.h"
 #include "k9prefpreview.h"
 #include "k9prefauthor.h"
+#include "k9prefdirs.h"
 #include <KPageDialog>
 
 /**
@@ -38,6 +39,7 @@ private:
     k9prefMencoder *m_prefMencoder;
     k9prefPreview *m_prefPreview;
     k9prefAuthor *m_prefAuthor;
+    k9prefDirs *m_prefDirs;
 private slots:
     void slotOkClicked();
     void slotApplyClicked();
